## Module for command simplification when using Python with the AWR Design Environment 

AWR Design Environment Python module that wraps lower level API commands into higher level function calls

# Installation
    pip install pyawr-utils

# Upgrade

    pip install --upgrade pyawr-utils

# Requirements
* Python >= 3.7
* pyawr
* numpy

# Usage

    See https://kb.awr.com/display/awrscripts/Pyawr+Utilities for details
	
# History

# 0.14
* Element dictionary update automatically when element is added or removed
# 0.13
* Added add_element(), remove element(), element xy_position()
* Fixed error in remove_schematic()
# 0.12
* Added equations to Schematics
# 0.11
* Fixed PyPI Installation and Upgrade commands
# 0.1
* Beta version


